#
# spec file for package logback
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           logback
Version:        1.2.11
Release:        3.4
Summary:        A Java logging library
License:        EPL-1.0 OR LGPL-2.1-or-later
URL:            https://logback.qos.ch/
Source0:        %{name}-%{version}.tar.xz
# Remove deprecated methods
Patch0:         %{name}-1.2.8-jetty.patch
Patch1:         logback-1.2.3-getCallerClass.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(javax.mail:mail)
BuildRequires:  mvn(javax.servlet:javax.servlet-api)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(log4j:log4j)
BuildRequires:  mvn(org.apache.ant:ant-junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.tomcat:tomcat-catalina)
BuildRequires:  mvn(org.apache.tomcat:tomcat-coyote)
BuildRequires:  mvn(org.codehaus.janino:janino)
BuildRequires:  mvn(org.eclipse.jetty:jetty-server)
BuildRequires:  mvn(org.eclipse.jetty:jetty-util)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-ext)
BuildArch:      noarch

%description
Logback is intended as a successor to the popular log4j project. At present
time, logback is divided into three modules, logback-core, logback-classic
and logback-access.

The logback-core module lays the groundwork for the other two modules. The
logback-classic module can be assimilated to a significantly improved
version of log4j. Moreover, logback-classic natively implements the SLF4J
API so that you can readily switch back and forth between logback and other
logging frameworks such as log4j or java.util.logging (JUL).

The logback-access module integrates with Servlet containers, such as
Tomcat and Jetty, to provide HTTP-access log functionality. Note that you
could easily build your own module on top of logback-core.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for the Logback library

%package access
Summary:        Logback-access module for Servlet integration

%description access
The logback-access module integrates with Servlet containers, such as Tomcat
and Jetty, to provide HTTP-access log functionality. Note that you could
easily build your own module on top of logback-core.

%package examples
Summary:        Logback Examples Module

%description examples
logback-examples module.

%prep
%setup -q
chmod -x README.md LICENSE.txt
find . -type f -exec chmod -x {} \;
chmod +x %{name}-examples/src/main/resources/setClasspath.sh

%patch -P 0 -p1
%patch -P 1 -p1

%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :findbugs-maven-plugin
%pom_remove_plugin -r :maven-dependency-plugin
%pom_remove_plugin -r :cobertura-maven-plugin

rm -r %{name}-*/src/test/java/*
# remove test deps
# ch.qos.logback:logback-core:test-jar
%pom_xpath_remove -r "pom:dependency[pom:type = 'test-jar']"
%pom_xpath_remove -r "pom:dependency[pom:scope = 'test']"

# bundle-test-jar
%pom_xpath_remove -r "pom:plugin[pom:artifactId = 'maven-jar-plugin']/pom:executions"

# com.oracle:ojdbc14:10.2.0.1 com.microsoft.sqlserver:sqljdbc4:2.0
%pom_xpath_remove "pom:project/pom:profiles/pom:profile[pom:id = 'host-orion']" %{name}-access

%pom_xpath_remove "pom:project/pom:profiles/pom:profile[pom:id = 'javadocjar']"

# disable for now
%pom_disable_module logback-site

%pom_xpath_remove "pom:build/pom:extensions"

%{mvn_package} ":%{name}-access" access
%{mvn_package} ":%{name}-examples" examples

%build

%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8 -Dproject.build.sourceEncoding=ISO-8859-1

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

install -d -m 755 %{buildroot}%{_datadir}/%{name}/examples
cp -r %{name}-examples/src %{buildroot}%{_datadir}/%{name}/examples
ln -sf %{_mavenpomdir}/%{name}/%{name}-examples.pom %{buildroot}%{_datadir}/%{name}/examples/pom.xml
%fdupes -s %{buildroot}%{_datadir}/%{name}

%files -f .mfiles
%doc README.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%files access -f .mfiles-access
%license LICENSE.txt

%files examples -f .mfiles-examples
%license LICENSE.txt
%{_datadir}/%{name}

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Thu Apr 28 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.2.11
  * Backported fix for LOGBACK-1027.
  * Fixed incorrect String cast in JNDIUtil. This corrects
    LOGBACK-1604.
  * In SMTPAppenderBase empty username parameter is now treated the
    same way as  null. This fixes LOGBACK-1594.
  * ContextInitializer no longer complains about missing
    logback.groovy configuration file. This fixes LOGBACK-1601.
  * In response to CVE-2021-42550 (aka LOGBACK-1591) the following
    steps were made:
    1) Hardened logback's JNDI lookup mechanism to only honor
    requests in the java: namespace. All other types of requests
    are ignored.
    2) SMTPAppender was hardened.
    3) Temporarily removed DB support for security reasons.
    4) Removed Groovy configuration support. As logging is so
    pervasive and configuration with Groovy is probably too
    powerful, this feature is unlikely to be reinstated for
    security reasons.
    The aforementioned vulnerability requires write access to
    logback's configuration file as a prerequisite. A successul
    RCE attack with CVE-2021-42550 requires all of the following
    conditions to be met:
    + write access to logback.xml
    + use of versions < 1.2.9
    + reloading of poisoned configuration data, which implies
    application restart or scan="true" set prior to attack
- Set project.build.sourceEncoding property to ISO-8859-1 to
  avoid the new maven-resources-plugin chocking on trying to filter
  in UTF-8 encoding JKS (binary) resources
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages
* Fri Dec 17 2021 Fridrich Strba <fstrba@suse.com>
- Do not execute goals generateTestStubs and compileTests of
  gmavenplus-plugin, since we are not compiling or runnig tests
  during the rpm build. This also allows us to use a wider range
  of gmavenplus-plugin versions, since those executions changed
  names in 1.6.
* Thu Dec 16 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.2.8 (bsc#1193795)
  * Changes of version 1.2.8
    + In response to LOGBACK-1591, all JNDI lookup code in logback
    has been disabled until further notice. This impacts
    ContextJNDISelector and <insertFromJNDI> element in
    configuration files.
    + Also in response to LOGBACK-1591, all database (JDBC) related
    code in the project has been removed with no replacement.
    + Note that the vulnerability mentioned in LOGBACK-1591 requires
    write access to logback's configuration file as a
    prerequisite. The log4Shell/CVE-2021-44228 and LOGBACK-1591
    are of different severity levels. A successful RCE requires
    all of the following conditions to be met:
  - write access to logback.xml
  - use of versions < 1.2.8
  - reloading of poisoned configuration data, which implies
    application restart or scan="true" set prior to attack
    + As an additional extra precaution, in addition to upgrading to
    logback version 1.2.8, the users are advised to set their
    logback configuration files as read-only.
  * Changes of version 1.2.7
    + Added hostnameVerification to property SSLSocketAppender.
    This fixes LOGBACK-1574.
  * Changes of version 1.2.6
    + To prevent XML eXternal Entity injection (XXE) attacks, Joran
    no longer reads external entities passed in XML files. This
    fixes LOGBACK-1465.
  * Changes of version 1.2.5
    + Instead of an Appender, the LayoutWrappingEncoder now accepts
    a variable of type ContextAware as a parent. This fixes
    LOGBACK-1326.
  * Changes of version 1.2.4
    + Added support for minimum length in %%i filename pattern. This
    fixes LOGBACK-1248.
    + For size bound log file archiving, allow
    TimeBasedArchiveRemove to remove files with indexes containing
    upto 5 digits. This fixes LOGBACK-1175.
    + Added %%prefix composite converter which automatically prefixes
    child converter output with the name of the converter. This
    feature is quite handy in environments where log files need to
    be parsed and monitored.
- Changed patch:
  * logback-1.1.11-jetty.patch -> logback-1.2.8-jetty.patch
    + Rediff to changed context
* Fri Nov 29 2019 Fridrich Strba <fstrba@suse.com>
- Do not force building with java < 9
- Specify maven.compiler.release=8 to access the
  java.util.function.Supplier API, introduced in java 8
- Added patch:
  * logback-1.2.3-getCallerClass.patch
    + Access the sun.reflect.Reflection.getCallerClass by
    reflection, in order to be able to build with jdk >= 9
* Sun Nov 17 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of logback 1.2.3
